@@ -153,7 +153,7 @@ class Crawler:
             while not success and trynum<=self.maxtrynum:
                 try:
                     r = requests.get(url, headers=self.getHeaders(), verify=False, timeout=self.timeout)
-                    r.encoding = 'UTF-8'
+                    r.encoding = r.apparent_encoding
                     success = True
                     trynum += 1
                 except requests.exceptions.ConnectTimeout as e1:
